@@ -3337,6 +3337,8 @@ fetch_corba_book (EBook       *book,
 	for (l = factories; l; l = l->next)
 		CORBA_Object_release ((CORBA_Object)l->data, NULL);
 
+	g_list_free (factories);
+
 	if (rv == TRUE) {
 		book->priv->corba_book = corba_book;
 		book->priv->comp_listener = e_component_listener_new (book->priv->corba_book);
@@ -3824,6 +3826,7 @@ e_book_new_from_uri (const char *uri, GError **error)
 	group = e_source_group_new ("", uri);
 	source = e_source_new ("", "");
 	e_source_set_group (source, group);
+	e_source_set_relative_uri (source, NULL);
 
 	book = e_book_new (source, error);
 
