@@ -369,7 +369,6 @@ set_attendees_to_item (EGwItem *item, ECalComponent *comp, icaltimezone *default
 					recipient->type = E_GW_ITEM_RECIPIENT_TO;
 
 					recipient_list = g_slist_prepend (recipient_list, recipient);
-					g_message (" email is %s \n", *iter);
 					iter++;
 				}
 
@@ -865,7 +864,6 @@ set_default_alarms (ECalComponent *comp)
 
 			interval = gconf_client_get_int (gconf, CALENDAR_CONFIG_DEFAULT_REMINDER_INTERVAL, NULL);
 			units = gconf_client_get_string (gconf, CALENDAR_CONFIG_DEFAULT_REMINDER_UNITS, NULL);
-			g_object_unref (gconf);
 
 			if (units == NULL) 
 				duration = MINUTES;
@@ -899,6 +897,7 @@ set_default_alarms (ECalComponent *comp)
 				break;
 			default:
 				e_cal_component_alarm_free (acomp);
+				g_object_unref (gconf);
 				return;
 			}
 
@@ -906,7 +905,8 @@ set_default_alarms (ECalComponent *comp)
 			e_cal_component_add_alarm (comp, acomp);
 
 			e_cal_component_alarm_free (acomp);
-			}
+		}
+		g_object_unref (gconf);
 }
 
 
@@ -2022,6 +2022,7 @@ e_cal_backend_groupwise_store_settings (EGwSendOptions *opts, ECalBackendGroupwi
 	}	
 
 	g_object_unref (gconf);
+	g_object_unref (source_list);
 }
 
 gboolean
